@@ -1,4 +1,5 @@
 """Defines a common set of exceptions which developers can raise and/or catch."""
+import requests
 
 
 class ConfigValidationError(Exception):
@@ -28,6 +29,16 @@ class RecordsWitoutSchemaException(Exception):
 class RetriableAPIError(Exception):
     """Exception raised when a failed request can be safely retried."""
 
+    def __init__(self, message: str, response: requests.Response = None) -> None:
+        """Extends the default with the failed response as an attribute.
+
+        Args:
+            message (str): The Error Message
+            response (requests.Response): The response object.
+        """
+        super().__init__(message)
+        self.response = response
+
 
 class StreamMapConfigError(Exception):
     """Raised when a stream map has an invalid configuration."""
