@@ -4,11 +4,10 @@ from copy import deepcopy
 from logging import Logger
 from typing import Any, Dict, Optional, Tuple
 
-from singer_sdk.helpers._singer import Catalog, SelectionMask
-from singer_sdk.helpers._typing import is_object_type
-
 from memoization import cached
 
+from singer_sdk.helpers._singer import Catalog, SelectionMask
+from singer_sdk.helpers._typing import is_object_type
 
 _MAX_LRU_CACHE = 500
 
@@ -45,6 +44,10 @@ def _pop_deselected_schema(
             f"'{type(schema_at_breadcrumb).__name__}' '{schema_at_breadcrumb}' "
             f"for '{stream_name}' bookmark '{str(breadcrumb)}' in '{schema}'"
         )
+
+    if "properties" not in schema_at_breadcrumb:
+        return
+
     for property_name, property_def in list(schema_at_breadcrumb["properties"].items()):
         property_breadcrumb: Tuple[str, ...] = tuple(
             list(breadcrumb) + ["properties", property_name]
