@@ -76,6 +76,9 @@ class Stream(metaclass=abc.ABCMeta):
     parent_stream_type: Optional[Type["Stream"]] = None
     ignore_parent_replication_key: bool = False
 
+    # Internal API cost aggregator
+    _sync_costs: Dict[str, int] = {}
+
     def __init__(
         self,
         tap: TapBaseClass,
@@ -431,19 +434,28 @@ class Stream(metaclass=abc.ABCMeta):
 
     @property
     def is_sorted(self) -> bool:
-        """Check if stream is sorted.
+        """Expect stream to be sorted.
 
         When `True`, incremental streams will attempt to resume if unexpectedly
         interrupted.
 
-        This setting enables additional checks which may trigger
-        `InvalidStreamSortException` if records are found which are unsorted.
-
         Returns:
             `True` if stream is sorted. Defaults to `False`.
         """
         return False
 
+    @property
+    def check_sorted(self) -> bool:
+        """Check if stream is sorted.
+
+        This setting enables additional checks which may trigger
+        `InvalidStreamSortException` if records are found which are unsorted.
+
+        Returns:
+            `True` if sorting is checked. Defaults to `True`.
+        """
+        return True
+
     @property
     def metadata(self) -> MetadataMapping:
         """Get stream metadata.
@@ -676,6 +688,7 @@ class Stream(metaclass=abc.ABCMeta):
                     replication_key=self.replication_key,
                     latest_record=latest_record,
                     is_sorted=treat_as_sorted,
+                    check_sorted=self.check_sorted,
                 )
 
     # Private message authoring methods:
@@ -854,6 +867,18 @@ class Stream(metaclass=abc.ABCMeta):
             extra_tags["context"] = context
         self._write_metric_log(metric=request_duration_metric, extra_tags=extra_tags)
 
+    def log_sync_costs(self) -> None:
+        """Log a summary of Sync costs.
+
+        The costs are calculated via `calculate_sync_cost`.
+        This method can be overridden to log results in a custom
+        format. It is only called once at the end of the life of
+        the stream.
+        """
+        if len(self._sync_costs) > 0:
+            msg = f"Total Sync costs for stream {self.name}: {self._sync_costs}"
+            self.logger.info(msg)
+
     def _check_max_record_limit(self, record_count: int) -> None:
         """TODO.
 
