@@ -1,8 +1,9 @@
 """Abstract base class for API-type streams."""
 
 import abc
-from typing import Iterable, Optional, Any
+from typing import Any, Optional
 
+from singer_sdk.helpers._classproperty import classproperty
 from singer_sdk.streams.rest import RESTStream
 
 
@@ -18,9 +19,22 @@ class GraphQLStream(RESTStream, metaclass=abc.ABCMeta):
     path = ""
     rest_method = "POST"
 
+    @classproperty
+    def records_jsonpath(cls) -> str:  # type: ignore  # OK: str vs @classproperty
+        """Get the JSONPath expression to extract records from an API response.
+
+        Returns:
+            JSONPath expression string
+        """
+        return f"$.data.{cls.name}[*]"
+
     @property
     def query(self) -> str:
-        """Set or return the GraphQL query string."""
+        """Set or return the GraphQL query string.
+
+        Raises:
+            NotImplementedError: If the derived class doesn't define this property.
+        """
         raise NotImplementedError("GraphQLStream `query` is not defined.")
 
     def prepare_request_payload(
@@ -31,6 +45,17 @@ class GraphQLStream(RESTStream, metaclass=abc.ABCMeta):
         Developers generally should generally not need to override this method.
         Instead, developers set the payload by properly configuring the `query`
         attribute.
+
+        Args:
+            context: Stream partition or context dictionary.
+            next_page_token: Token, page number or any request argument to request the
+                next page of data.
+
+        Returns:
+            Dictionary with the body to use for the request.
+
+        Raises:
+            ValueError: If the `query` property is not set in the request body.
         """
         params = self.get_url_params(context, next_page_token)
         if self.query is None:
@@ -47,9 +72,3 @@ class GraphQLStream(RESTStream, metaclass=abc.ABCMeta):
         }
         self.logger.debug(f"Attempting query:\n{query}")
         return request_data
-
-    def parse_response(self, response) -> Iterable[dict]:
-        """Parse the response and return an iterator of result rows."""
-        resp_json = response.json()
-        for row in resp_json["data"][self.name]:
-            yield row
