@@ -4,7 +4,18 @@ import abc
 import copy
 import logging
 from datetime import datetime
-from typing import Any, Callable, Dict, Generator, Iterable, List, Optional, Union, cast
+from typing import (
+    Any,
+    Callable,
+    Dict,
+    Generator,
+    Generic,
+    Iterable,
+    List,
+    Optional,
+    TypeVar,
+    Union,
+)
 
 import backoff
 import requests
@@ -19,8 +30,10 @@ from singer_sdk.streams.core import Stream
 DEFAULT_PAGE_SIZE = 1000
 DEFAULT_REQUEST_TIMEOUT = 300  # 5 minutes
 
+_TToken = TypeVar("_TToken")
 
-class RESTStream(Stream, metaclass=abc.ABCMeta):
+
+class RESTStream(Stream, Generic[_TToken], metaclass=abc.ABCMeta):
     """Abstract base class for REST API streams."""
 
     _page_size: int = DEFAULT_PAGE_SIZE
@@ -237,7 +250,7 @@ class RESTStream(Stream, metaclass=abc.ABCMeta):
         return response
 
     def get_url_params(
-        self, context: Optional[dict], next_page_token: Optional[Any]
+        self, context: Optional[dict], next_page_token: Optional[_TToken]
     ) -> Dict[str, Any]:
         """Return a dictionary of values to be used in URL parameterization.
 
@@ -254,7 +267,7 @@ class RESTStream(Stream, metaclass=abc.ABCMeta):
         return {}
 
     def prepare_request(
-        self, context: Optional[dict], next_page_token: Optional[Any]
+        self, context: Optional[dict], next_page_token: Optional[_TToken]
     ) -> requests.PreparedRequest:
         """Prepare a request object.
 
@@ -282,16 +295,13 @@ class RESTStream(Stream, metaclass=abc.ABCMeta):
             headers.update(authenticator.auth_headers or {})
             params.update(authenticator.auth_params or {})
 
-        request = cast(
-            requests.PreparedRequest,
-            self.requests_session.prepare_request(
-                requests.Request(
-                    method=http_method,
-                    url=url,
-                    params=params,
-                    headers=headers,
-                    json=request_data,
-                ),
+        request = self.requests_session.prepare_request(
+            requests.Request(
+                method=http_method,
+                url=url,
+                params=params,
+                headers=headers,
+                json=request_data,
             ),
         )
         return request
@@ -311,7 +321,7 @@ class RESTStream(Stream, metaclass=abc.ABCMeta):
             RuntimeError: If a loop in pagination is detected. That is, when two
                 consecutive pagination tokens are identical.
         """
-        next_page_token: Any = None
+        next_page_token: Optional[_TToken] = None
         finished = False
         decorated_request = self.request_decorator(self._request)
 
@@ -320,6 +330,7 @@ class RESTStream(Stream, metaclass=abc.ABCMeta):
                 context, next_page_token=next_page_token
             )
             resp = decorated_request(prepared_request, context)
+            self.update_sync_costs(prepared_request, resp, context)
             yield from self.parse_response(resp)
             previous_token = copy.deepcopy(next_page_token)
             next_page_token = self.get_next_page_token(
@@ -333,10 +344,65 @@ class RESTStream(Stream, metaclass=abc.ABCMeta):
             # Cycle until get_next_page_token() no longer returns a value
             finished = not next_page_token
 
+    def update_sync_costs(
+        self,
+        request: requests.PreparedRequest,
+        response: requests.Response,
+        context: Optional[Dict],
+    ) -> Dict[str, int]:
+        """Update internal calculation of Sync costs.
+
+        Args:
+            request: the Request object that was just called.
+            response: the `requests.Response` object
+            context: the context passed to the call
+
+        Returns:
+            A dict of costs (for the single request) whose keys are
+            the "cost domains". See `calculate_sync_cost` for details.
+        """
+        call_costs = self.calculate_sync_cost(request, response, context)
+        self._sync_costs = {
+            k: self._sync_costs.get(k, 0) + call_costs.get(k, 0)
+            for k in call_costs.keys()
+        }
+        return self._sync_costs
+
     # Overridable:
 
+    def calculate_sync_cost(
+        self,
+        request: requests.PreparedRequest,
+        response: requests.Response,
+        context: Optional[Dict],
+    ) -> Dict[str, int]:
+        """Calculate the cost of the last API call made.
+
+        This method can optionally be implemented in streams to calculate
+        the costs (in arbitrary units to be defined by the tap developer)
+        associated with a single API/network call. The request and response objects
+        are available in the callback, as well as the context.
+
+        The method returns a dict where the keys are arbitrary cost dimensions,
+        and the values the cost along each dimension for this one call. For
+        instance: { "rest": 0, "graphql": 42 } for a call to github's graphql API.
+        All keys should be present in the dict.
+
+        This method can be overridden by tap streams. By default it won't do
+        anything.
+
+        Args:
+            request: the API Request object that was just called.
+            response: the `requests.Response` object
+            context: the context passed to the call
+
+        Returns:
+            A dict of accumulated costs whose keys are the "cost domains".
+        """
+        return {}
+
     def prepare_request_payload(
-        self, context: Optional[dict], next_page_token: Optional[Any]
+        self, context: Optional[dict], next_page_token: Optional[_TToken]
     ) -> Optional[dict]:
         """Prepare the data payload for the REST API request.
 
@@ -357,8 +423,10 @@ class RESTStream(Stream, metaclass=abc.ABCMeta):
         return None
 
     def get_next_page_token(
-        self, response: requests.Response, previous_token: Optional[Any]
-    ) -> Any:
+        self,
+        response: requests.Response,
+        previous_token: Optional[_TToken],
+    ) -> Optional[_TToken]:
         """Return token identifying next page or None if all records have been read.
 
         Args:
@@ -463,8 +531,7 @@ class RESTStream(Stream, metaclass=abc.ABCMeta):
         See for options:
         https://github.com/litl/backoff/blob/master/backoff/_wait_gen.py
 
-        And see for examples:
-        https://sdk.meltano.com/en/latest/code_samples.html#custom-backoff
+        And see for examples: `Code Samples <../code_samples.html#custom-backoff>`_
 
         Returns:
             The wait generator
@@ -474,7 +541,7 @@ class RESTStream(Stream, metaclass=abc.ABCMeta):
     def backoff_max_tries(self) -> int:
         """The number of attempts before giving up when retrying requests.
 
-        Setting to None will retry indefinetely.
+        Setting to None will retry indefinitely.
 
         Returns:
             int: limit
