@@ -8,6 +8,8 @@ from typing import Any, Dict, Iterable, List, Optional, Tuple, Type, Union, cast
 
 import singer
 import sqlalchemy
+from sqlalchemy.engine import Engine
+from sqlalchemy.engine.reflection import Inspector
 
 from singer_sdk import typing as th
 from singer_sdk.exceptions import ConfigValidationError
@@ -96,7 +98,7 @@ class SQLConnector:
         Returns:
             A newly created SQLAlchemy engine object.
         """
-        return sqlalchemy.create_engine(self.sqlalchemy_url, echo=True)
+        return sqlalchemy.create_engine(self.sqlalchemy_url, echo=False)
 
     @property
     def connection(self) -> sqlalchemy.engine.Connection:
@@ -289,6 +291,134 @@ class SQLConnector:
             "Streams list may be incomplete or `is_view` may be unpopulated."
         )
 
+    def get_schema_names(self, engine: Engine, inspected: Inspector) -> List[str]:
+        """Return a list of schema names in DB.
+
+        Args:
+            engine: SQLAlchemy engine
+            inspected: SQLAlchemy inspector instance for engine
+
+        Returns:
+            List of schema names
+        """
+        return inspected.get_schema_names()
+
+    def get_object_names(
+        self, engine: Engine, inspected: Inspector, schema_name: str
+    ) -> List[Tuple[str, bool]]:
+        """Return a list of syncable objects.
+
+        Args:
+            engine: SQLAlchemy engine
+            inspected: SQLAlchemy inspector instance for engine
+            schema_name: Schema name to inspect
+
+        Returns:
+            List of tuples (<table_or_view_name>, <is_view>)
+        """
+        # Get list of tables and views
+        table_names = inspected.get_table_names(schema=schema_name)
+        try:
+            view_names = inspected.get_view_names(schema=schema_name)
+        except NotImplementedError:
+            # Some DB providers do not understand 'views'
+            self._warn_no_view_detection()
+            view_names = []
+        object_names = [(t, False) for t in table_names] + [
+            (v, True) for v in view_names
+        ]
+
+        return object_names
+
+    # TODO maybe should be splitted into smaller parts?
+    def discover_catalog_entry(
+        self,
+        engine: Engine,
+        inspected: Inspector,
+        schema_name: str,
+        table_name: str,
+        is_view: bool,
+    ) -> CatalogEntry:
+        """Create `CatalogEntry` object for the given table or a view.
+
+        Args:
+            engine: SQLAlchemy engine
+            inspected: SQLAlchemy inspector instance for engine
+            schema_name: Schema name to inspect
+            table_name: Name of the table or a view
+            is_view: Flag whether this object is a view, returned by `get_object_names`
+
+        Returns:
+            `CatalogEntry` object for the given table or a view
+        """
+        # Initialize unique stream name
+        unique_stream_id = self.get_fully_qualified_name(
+            db_name=None,
+            schema_name=schema_name,
+            table_name=table_name,
+            delimiter="-",
+        )
+
+        # Detect key properties
+        possible_primary_keys: List[List[str]] = []
+        pk_def = inspected.get_pk_constraint(table_name, schema=schema_name)
+        if pk_def and "constrained_columns" in pk_def:
+            possible_primary_keys.append(pk_def["constrained_columns"])
+        for index_def in inspected.get_indexes(table_name, schema=schema_name):
+            if index_def.get("unique", False):
+                possible_primary_keys.append(index_def["column_names"])
+        key_properties = next(iter(possible_primary_keys), None)
+
+        # Initialize columns list
+        table_schema = th.PropertiesList()
+        for column_def in inspected.get_columns(table_name, schema=schema_name):
+            column_name = column_def["name"]
+            is_nullable = column_def.get("nullable", False)
+            jsonschema_type: dict = self.to_jsonschema_type(
+                cast(sqlalchemy.types.TypeEngine, column_def["type"])
+            )
+            table_schema.append(
+                th.Property(
+                    name=column_name,
+                    wrapped=th.CustomType(jsonschema_type),
+                    required=not is_nullable,
+                )
+            )
+        schema = table_schema.to_dict()
+
+        # Initialize available replication methods
+        addl_replication_methods: List[str] = [""]  # By default an empty list.
+        # Notes regarding replication methods:
+        # - 'INCREMENTAL' replication must be enabled by the user by specifying
+        #   a replication_key value.
+        # - 'LOG_BASED' replication must be enabled by the developer, according
+        #   to source-specific implementation capabilities.
+        replication_method = next(reversed(["FULL_TABLE"] + addl_replication_methods))
+
+        # Create the catalog entry object
+        catalog_entry = CatalogEntry(
+            tap_stream_id=unique_stream_id,
+            stream=unique_stream_id,
+            table=table_name,
+            key_properties=key_properties,
+            schema=singer.Schema.from_dict(schema),
+            is_view=is_view,
+            replication_method=replication_method,
+            metadata=MetadataMapping.get_standard_metadata(
+                schema_name=schema_name,
+                schema=schema,
+                replication_method=replication_method,
+                key_properties=key_properties,
+                valid_replication_keys=None,  # Must be defined by user
+            ),
+            database=None,  # Expects single-database context
+            row_count=None,
+            stream_alias=None,
+            replication_key=None,  # Must be defined by user
+        )
+
+        return catalog_entry
+
     def discover_catalog_entries(self) -> List[dict]:
         """Return a list of catalog entries from discovery.
 
@@ -298,87 +428,13 @@ class SQLConnector:
         result: List[dict] = []
         engine = self.create_sqlalchemy_engine()
         inspected = sqlalchemy.inspect(engine)
-        for schema_name in inspected.get_schema_names():
-            # Get list of tables and views
-            table_names = inspected.get_table_names(schema=schema_name)
-            try:
-                view_names = inspected.get_view_names(schema=schema_name)
-            except NotImplementedError:
-                # Some DB providers do not understand 'views'
-                self._warn_no_view_detection()
-                view_names = []
-            object_names = [(t, False) for t in table_names] + [
-                (v, True) for v in view_names
-            ]
-
+        for schema_name in self.get_schema_names(engine, inspected):
             # Iterate through each table and view
-            for table_name, is_view in object_names:
-                # Initialize unique stream name
-                unique_stream_id = self.get_fully_qualified_name(
-                    db_name=None,
-                    schema_name=schema_name,
-                    table_name=table_name,
-                    delimiter="-",
-                )
-
-                # Detect key properties
-                possible_primary_keys: List[List[str]] = []
-                pk_def = inspected.get_pk_constraint(table_name, schema=schema_name)
-                if pk_def and "constrained_columns" in pk_def:
-                    possible_primary_keys.append(pk_def["constrained_columns"])
-                for index_def in inspected.get_indexes(table_name, schema=schema_name):
-                    if index_def.get("unique", False):
-                        possible_primary_keys.append(index_def["column_names"])
-                key_properties = next(iter(possible_primary_keys), None)
-
-                # Initialize columns list
-                table_schema = th.PropertiesList()
-                for column_def in inspected.get_columns(table_name, schema=schema_name):
-                    column_name = column_def["name"]
-                    is_nullable = column_def.get("nullable", False)
-                    jsonschema_type: dict = self.to_jsonschema_type(
-                        cast(sqlalchemy.types.TypeEngine, column_def["type"])
-                    )
-                    table_schema.append(
-                        th.Property(
-                            name=column_name,
-                            wrapped=th.CustomType(jsonschema_type),
-                            required=not is_nullable,
-                        )
-                    )
-                schema = table_schema.to_dict()
-
-                # Initialize available replication methods
-                addl_replication_methods: List[str] = [""]  # By default an empty list.
-                # Notes regarding replication methods:
-                # - 'INCREMENTAL' replication must be enabled by the user by specifying
-                #   a replication_key value.
-                # - 'LOG_BASED' replication must be enabled by the developer, according
-                #   to source-specific implementation capabilities.
-                replication_method = next(
-                    reversed(["FULL_TABLE"] + addl_replication_methods)
-                )
-
-                # Create the catalog entry object
-                catalog_entry = CatalogEntry(
-                    tap_stream_id=unique_stream_id,
-                    stream=unique_stream_id,
-                    table=table_name,
-                    key_properties=key_properties,
-                    schema=singer.Schema.from_dict(schema),
-                    is_view=is_view,
-                    replication_method=replication_method,
-                    metadata=MetadataMapping.get_standard_metadata(
-                        schema_name=schema_name,
-                        schema=schema,
-                        replication_method=replication_method,
-                        key_properties=key_properties,
-                        valid_replication_keys=None,  # Must be defined by user
-                    ),
-                    database=None,  # Expects single-database context
-                    row_count=None,
-                    stream_alias=None,
-                    replication_key=None,  # Must be defined by user
+            for table_name, is_view in self.get_object_names(
+                engine, inspected, schema_name
+            ):
+                catalog_entry = self.discover_catalog_entry(
+                    engine, inspected, schema_name, table_name, is_view
                 )
                 result.append(catalog_entry.to_dict())
 
